slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPValuesView

Displays the computed eigenvalues in a viewer.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPValuesView(PEP pep,PetscViewer viewer)

Collective on pep

### Input Parameters

| pep | - the eigensolver context
| viewer | - the viewer

### Options Database Key

| -pep_view_values | - print computed eigenvalues

### See Also

PEPSolve(), PEPVectorsView(), PEPErrorView()

### Level

intermediate

### Location

src/pep/interface/pepview.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages